@@ -1,13 +1,3 @@
-schema_install() {
-  SCHEMA="$1"
-  GCONF_CONFIG_SOURCE="xml::etc/gconf/gconf.xml.defaults" \
-  chroot . gconftool-2 --makefile-install-rule \
-    /etc/gconf/schemas/$SCHEMA \
-    1>/dev/null 2> /dev/null
-}
-
-schema_install nm-applet.schemas
-
 if [ -x /usr/bin/update-desktop-database ]; then
   /usr/bin/update-desktop-database -q usr/share/applications 1>/dev/null 2> /dev/null
 fi
@@ -18,7 +8,13 @@ if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
   fi
 fi
 
-( cd usr/lib ; rm -rf libnm-gtk.so.0 )
-( cd usr/lib ; ln -sf libnm-gtk.so.0.0.0 libnm-gtk.so.0 )
+if [ -e usr/share/glib-2.0/schemas ]; then
+  if [ -x /usr/bin/glib-compile-schemas ]; then
+    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
+  fi
+fi
+
 ( cd usr/lib ; rm -rf libnm-gtk.so )
 ( cd usr/lib ; ln -sf libnm-gtk.so.0.0.0 libnm-gtk.so )
+( cd usr/lib ; rm -rf libnm-gtk.so.0 )
+( cd usr/lib ; ln -sf libnm-gtk.so.0.0.0 libnm-gtk.so.0 )
